@@ -2,7 +2,9 @@ test_that("joining data frame requires explicit copy", {
   pf <- partition(data.frame(x = 1:6), default_cluster())
   df <- data.frame(x = 1:3, y = 3:1)
 
-  expect_error(left_join(pf, df), "same src")
+  expect_snapshot(error = TRUE, {
+    left_join(pf, df)
+  })
   expect_error(left_join(pf, df, copy = TRUE), NA)
 })
 
