@@ -17,14 +17,14 @@ test_that("can construct and print partydf", {
 
 test_that("name must be data frame with same names", {
   cl <- default_cluster()
-  expect_error(party_df(cl, "x"), "does not exist")
+  expect_snapshot(error = TRUE, party_df(cl, "x"))
 
   cluster_assign(cl, x = 1)
   on.exit(cluster_rm(cl, "x"))
-  expect_error(party_df(cl, "x"), "not a data frame")
+  expect_snapshot(error = TRUE, party_df(cl, "x"))
 
   cluster_assign_each(cl, x = list(tibble(x = 1), tibble(y = 2)))
-  expect_error(party_df(cl, "x"), "same names")
+  expect_snapshot(error = TRUE, party_df(cl, "x"))
 })
 
 test_that("can automatically delete on gc() + cluster_call()", {
@@ -32,7 +32,8 @@ test_that("can automatically delete on gc() + cluster_call()", {
   cl <- cluster_assign(cl, x = data.frame(y = 1:10))
 
   df <- party_df(cl, "x", auto_rm = TRUE)
-  rm(df); gc()
+  rm(df)
+  gc()
   expect_equal(cluster_call(cl, exists("x")), list(FALSE, FALSE))
 })
 
@@ -57,10 +58,13 @@ test_that("can partition by group", {
   df2 <- df1 %>% group_by(x) %>% partition(cl)
 
   dfs <- cluster_call(cl, !!df2$name)
-  expect_equal(dfs, list(
-    group_by(tibble(x = c(1, 1)), x),
-    group_by(tibble(x = c(2, 3)), x)
-  ))
+  expect_equal(
+    dfs,
+    list(
+      group_by(tibble(x = c(1, 1)), x),
+      group_by(tibble(x = c(2, 3)), x)
+    )
+  )
 })
 
 test_that("reduce cluster size if needed", {
